package com.dataart.viewer.product.converter;

import com.dataart.viewer.product.mapper.ErrorMapper;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.commons.lang.Validate;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;

import org.springframework.stereotype.Component;
import org.springframework.validation.Errors;
import org.springframework.validation.ObjectError;

/**
 * Converting data to ExtJS compatible format
 *
 * @author volkodavav
 */
@Component
public class ExtJsConverter implements InitializingBean {

    protected Logger logger = LoggerFactory.getLogger(getClass());
    @Autowired
    protected ErrorMapper errorMapper;
    @Autowired
    protected JsonConverter jsonConverter;

    public <T> Map<String, Object> transformSuccess(Collection<T> items) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        modelMap.put("total", items.size());
        modelMap.put("data", items);
        modelMap.put("success", true);

        return modelMap;
    }

    public <T> Map<String, Object> transformSuccess(T item) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        modelMap.put("data", item);
        modelMap.put("success", true);

        return modelMap;
    }

    public <T> Map<String, Object> transformSuccess(Collection<T> items, int total) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        modelMap.put("total", total);
        modelMap.put("data", items);
        modelMap.put("success", true);

        return modelMap;
    }

    public <T> Map<String, Object> transformSuccess(Page<T> page) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        modelMap.put("total", page.getTotalElements());
        modelMap.put("data", page.getContent());
        modelMap.put("success", true);

        return modelMap;
    }

    public <T> Map<String, Object> transformError(String message, Exception t) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        modelMap.put("message", message);
        modelMap.put("success", false);

        return modelMap;
    }

    public Map<String, Object> transformErrors(Errors errors) {
        Map<String, Object> modelMap = new HashMap<String, Object>();

        Map<String, String> errorsMap = errorMapper.transformErrors(errors);

        modelMap.put("message", errorsMap);
        modelMap.put("success", false);
        return modelMap;
    }

    public Map<String, Object> transformErrors(List<ObjectError> errors) {
        Map<String, Object> modelMap = new HashMap<String, Object>();

        Map<String, String> errorsMap = errorMapper.transformErrors(errors);

        modelMap.put("message", errorsMap);
        modelMap.put("success", false);
        return modelMap;
    }

    public void setErrorMapper(ErrorMapper errorMapper) {
        this.errorMapper = errorMapper;
    }

    public void setJsonConverter(JsonConverter jsonConverter) {
        this.jsonConverter = jsonConverter;
    }

    @Override
    public void afterPropertiesSet() throws Exception {
        Validate.notNull(errorMapper, "errorMapper expected");
        Validate.notNull(jsonConverter, "jsonConverter expected");
    }
}
