package com.dataart.viewer.product.converter;

import java.io.IOException;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.List;
import org.codehaus.jackson.JsonParseException;
import org.codehaus.jackson.map.JsonMappingException;
import org.codehaus.jackson.map.ObjectMapper;
import org.codehaus.jackson.map.type.TypeFactory;
import org.codehaus.jackson.type.TypeReference;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

/**
 * Converting data from/to JSON format
 *
 * @author volkodavav
 */
@Component
public class JsonConverter {

    protected Logger logger = LoggerFactory.getLogger(getClass());

    public <T> T fromStringToObject(TypeReference<T> typeReference, String jsonString) {
        try {
            ObjectMapper mapper = new ObjectMapper();

            return mapper.readValue(jsonString, typeReference);
        } catch (JsonParseException ex) {
            logger.error(ex.getMessage(), ex);
        } catch (JsonMappingException ex) {
            logger.error(ex.getMessage(), ex);
        } catch (IOException ex) {
            logger.error(ex.getMessage(), ex);
        }

        return null;
    }

    public <T> String fromObjectToString(T object) {
        try {
            StringWriter sw = new StringWriter();
            ObjectMapper mapper = new ObjectMapper();
            mapper.writeValue(sw, object);

            return sw.toString();
        } catch (JsonParseException ex) {
            logger.error(ex.getMessage(), ex);
        } catch (JsonMappingException ex) {
            logger.error(ex.getMessage(), ex);
        } catch (IOException ex) {
            logger.error(ex.getMessage(), ex);
        }

        return null;
    }

    public <T> List<T> mapJsonToObjectList(T typeDef, String json, Class clazz) {
        try {
            List<T> list;
            ObjectMapper mapper = new ObjectMapper();
            logger.info("json: {}", json);
            TypeFactory t = TypeFactory.defaultInstance();
            list = mapper.readValue(json, t.constructCollectionType(ArrayList.class, clazz));

            logger.info("list: {}", list);
            logger.info("list.get(0).getClass(): {}", list.get(0).getClass());
            return list;
        } catch (JsonParseException ex) {
            logger.error(ex.getMessage(), ex);
        } catch (JsonMappingException ex) {
            logger.error(ex.getMessage(), ex);
        } catch (IOException ex) {
            logger.error(ex.getMessage(), ex);
        }

        return null;
    }
}
