package com.dataart.viewer.product.mapper;

import com.dataart.viewer.product.model.impl.ProductGroup;
import com.dataart.viewer.product.model.vo.ProductGroupVO;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;

/**
 *
 * @author volkodavav
 */
@Service
public class ProductGroupMapper {

    public ProductGroup toPersistence(ProductGroupVO productGroupVO) {
        if (productGroupVO == null) {
            return null;
        }

        ProductGroup productGroup = new ProductGroup();
        productGroup.setName(productGroupVO.getName());

        return productGroup;
    }

    public List<ProductGroup> toPersistence(List<ProductGroupVO> productGroupsVO) {
        if (productGroupsVO == null || productGroupsVO.isEmpty()) {
            return Collections.EMPTY_LIST;
        }

        List<ProductGroup> productGroups = new ArrayList<ProductGroup>(productGroupsVO.size());

        for (ProductGroupVO entry : productGroupsVO) {
            productGroups.add(toPersistence(entry));
        }

        return productGroups;
    }

    public ProductGroupVO toVO(ProductGroup productGroup) {
        if (productGroup == null) {
            return null;
        }

        ProductGroupVO productGroupVO = new ProductGroupVO();
        productGroupVO.setName(productGroup.getName());

        return productGroupVO;
    }

    public List<ProductGroupVO> toVO(List<ProductGroup> productGroups) {
        if (productGroups == null || productGroups.isEmpty()) {
            return Collections.EMPTY_LIST;
        }

        List<ProductGroupVO> productGroupsVO = new ArrayList<ProductGroupVO>(productGroups.size());

        for (ProductGroup entry : productGroups) {
            productGroupsVO.add(toVO(entry));
        }

        return productGroupsVO;
    }

    public Page<ProductGroupVO> toVO(Page<ProductGroup> productGroups, Pageable pageable) {
        Page<ProductGroupVO> voResult = new PageImpl<ProductGroupVO>(
            toVO(productGroups.getContent()), pageable,
            productGroups.getTotalElements());

        return voResult;
    }
}
