package com.dataart.viewer.product.mapper;

import com.dataart.viewer.product.model.impl.Product;
import com.dataart.viewer.product.model.impl.ProductGroup;
import com.dataart.viewer.product.model.vo.ProductVO;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;

/**
 *
 * @author volkodavav
 */
@Service
public class ProductMapper {

    public Product toPersistence(ProductVO productVO) {
        if (productVO == null) {
            return null;
        }

        Product product = new Product();
        product.setName(productVO.getName());
        product.setPrice(productVO.getPrice());

        ProductGroup group = new ProductGroup();
        group.setName(productVO.getGroup());
        product.setGroup(group);

        return product;
    }

    public List<Product> toPersistence(List<ProductVO> productsVO) {
        if (productsVO == null || productsVO.isEmpty()) {
            return Collections.EMPTY_LIST;
        }

        List<Product> products = new ArrayList<Product>(productsVO.size());

        for (ProductVO entry : productsVO) {
            products.add(toPersistence(entry));
        }

        return products;
    }

    public ProductVO toVO(Product product) {
        if (product == null) {
            return null;
        }

        ProductVO productVO = new ProductVO();
        productVO.setName(product.getName());
        productVO.setPrice(product.getPrice());

        ProductGroup productGroup = product.getGroup();
        if (productGroup != null) {
            productVO.setGroup(productGroup.getName());
        }

        return productVO;
    }

    public List<ProductVO> toVO(List<Product> products) {
        if (products == null || products.isEmpty()) {
            return Collections.EMPTY_LIST;
        }

        List<ProductVO> productsVO = new ArrayList<ProductVO>(products.size());

        for (Product entry : products) {
            productsVO.add(toVO(entry));
        }

        return productsVO;
    }

    public Page<ProductVO> toVO(Page<Product> products, Pageable pageable) {
        Page<ProductVO> voResult = new PageImpl<ProductVO>(
            toVO(products.getContent()), pageable,
            products.getTotalElements());

        return voResult;
    }
}
