package com.dataart.viewer.product.service.impl;

import com.dataart.viewer.product.mapper.ProductGroupMapper;
import com.dataart.viewer.product.model.impl.ProductGroup;
import com.dataart.viewer.product.model.vo.ProductGroupVO;
import com.dataart.viewer.product.repository.ProductGroupRepository;
import com.dataart.viewer.product.service.ProductGroupService;
import org.apache.commons.lang.Validate;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 *
 * @author volkodavav
 */
@Transactional(readOnly = true)
@Service
public class ProductGroupServiceDefault implements ProductGroupService, InitializingBean {

    protected Logger logger = LoggerFactory.getLogger(getClass());
    @Autowired
    private ProductGroupRepository productGroupRepository;
    @Autowired
    private ProductGroupMapper productGroupMapper;

    @Transactional
    @Override
    public void deleteAllGroups() {
        productGroupRepository.deleteAll();
    }

    @Transactional
    @Override
    public ProductGroupVO save(ProductGroupVO productGroupVO) {
        Validate.notNull(productGroupVO, "Product group must not be null");

        ProductGroup productGroup = productGroupMapper.toPersistence(productGroupVO);
        ProductGroup savedProductGroup = productGroupRepository.save(productGroup);
        return productGroupMapper.toVO(savedProductGroup);
    }

    public void setProductGroupRepository(ProductGroupRepository productGroupRepository) {
        this.productGroupRepository = productGroupRepository;
    }

    public void setProductGroupMapper(ProductGroupMapper productGroupMapper) {
        this.productGroupMapper = productGroupMapper;
    }

    @Override
    public void afterPropertiesSet() throws Exception {
        Validate.notNull(productGroupRepository, "productGroupRepository expected");
        Validate.notNull(productGroupMapper, "productGroupMapper expected");
    }
}
