package com.dataart.viewer.product.util;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Component;

/**
 *
 * @author volkodavav
 */
@Component
public class PageUtil {

    protected Logger logger = LoggerFactory.getLogger(getClass());

    public Pageable createPageable(int start, int limit, int total, Sort sort) {
        logger.info("Creating pageable object with start: {}, limit {}, total: {}", start, limit, total);
        int page = getPage(start, limit, total);
        logger.info("For page: {}", page);
        Pageable pageable;

        if (sort != null) {
            pageable = new PageRequest(page, limit, sort);
        } else {
            pageable = new PageRequest(page, limit);
        }

        logger.info("Pageable created: {}", pageable);
        return pageable;
    }

    private int getPage(int start, int limit, int total) {
        int page;

        if (total != -1 && start >= total) {
            start = 0;
        }
        if (start >= 0 && limit > 0) {
            page = (int) Math.floor(start / limit);
        } else {
            page = 0;
        }

        return page;
    }
}
