package com.dataart.viewer.product.web.controller;

import com.dataart.viewer.product.exception.ApplicationException;
import java.util.Map;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

/**
 *
 * @author volkodavav
 */
public abstract class BaseRestController extends BaseController {

    // do not pass validation
    @ResponseStatus(HttpStatus.BAD_REQUEST)
    @ExceptionHandler(value = {MethodArgumentNotValidException.class})
    @ResponseBody
    public Map<String, ? extends Object> handleMethodArgumentNotValidException(MethodArgumentNotValidException e) {
        return extJsConverter.transformErrors(e.getBindingResult());
    }

    @ResponseStatus(HttpStatus.BAD_REQUEST)
    @ExceptionHandler(value = {ApplicationException.class})
    @ResponseBody
    public Map<String, ? extends Object> handleApplicationException(ApplicationException e) {
        logger.error(e.getMessage(), e);
        return extJsConverter.transformError(simpleExceptionHandler(e), e);
    }

    @ResponseStatus(HttpStatus.INTERNAL_SERVER_ERROR)
    @ExceptionHandler(value = {Exception.class})
    @ResponseBody
    public Map<String, ? extends Object> handleException(Exception e) {
        logger.error(e.getMessage(), e);
        return extJsConverter.transformError(simpleExceptionHandler(e), e);
    }
}
