package com.dataart.viewer.product.web.controller;

import com.dataart.viewer.product.model.vo.ProductVO;
import com.dataart.viewer.product.model.vo.ProductGroupResultVO;
import com.dataart.viewer.product.service.ProductService;
import java.util.List;
import java.util.Map;
import org.apache.commons.lang.Validate;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

/**
 * Product REST controller.
 *
 * @author volkodavav
 */
@Controller
@RequestMapping("/product")
public class ProductRestController extends BaseRestController {

    protected Logger logger = LoggerFactory.getLogger(getClass());
    @Autowired
    protected ProductService productService;

    @RequestMapping(value = "/getAllProducts.action", method = RequestMethod.GET)
    @ResponseBody
    public Map<String, ? extends Object> getAllProducts(
        @RequestParam(value = "totalCount", required = false, defaultValue = "-1") int totalCount,
        @RequestParam(value = "start", required = false, defaultValue = "0") int start,
        @RequestParam(value = "limit", required = false, defaultValue = "3") int limit,
        @RequestParam(value = "page", required = false, defaultValue = "1") int page,
        @RequestParam(value = "filter", required = false) String filterJson,
        @RequestParam(value = "sort", required = false) String sortJson) {

        logger.info("Get all products from {} limited with {}. Page: {}. Size: {}", start, limit, page, totalCount);
        logger.info("Get all products by Filter: {} ; and Sort {}", filterJson, sortJson);

        try {
            Page<ProductVO> result = productService.getCurrentPage(start, limit, totalCount, filterJson, sortJson);

            return extJsConverter.transformSuccess(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return extJsConverter.transformError("Couldn't retrieve products: " + e.getMessage(), e);
        }
    }

    @RequestMapping(value = "/countProductsGroupedByGroupName.action", method = RequestMethod.GET)
    @ResponseBody
    public Map<String, ? extends Object> countProductsGroupedByGroupName() {
        logger.info("Count products grouped by product group name");

        try {
            List<ProductGroupResultVO> result = productService.countProductsGroupedByGroupName();

            return extJsConverter.transformSuccess(result);
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return extJsConverter.transformError("Couldn't retrieve products: " + e.getMessage(), e);
        }
    }

    public void setProductService(ProductService productService) {
        this.productService = productService;
    }

    @Override
    public void afterPropertiesSet() throws Exception {
        super.afterPropertiesSet();

        Validate.notNull(productService, "productService expected");
    }
}
