Ext.define('DataArt.controller.ProductGroups', {
  extend: 'Ext.app.Controller',
  views: ['productGroup.List'],
  refs: [{
      ref: 'productlist',
      selector: 'productlist',
      xtype: 'productlist',
      autoCreate: true
    }, {
      ref: 'productgrouplist',
      selector: 'productgrouplist'
    }
  ],
  dialogUtil: Ext.create("Shared.lib.DialogUtil"),
  requestUtil: Ext.create("Shared.lib.RequestUtil"),
  init: function() {
    var me = this;

    me.control({
      'productgrouplist': {
        beforerender: me.buildProductGroups
      },
      'productgrouplist dataview': {
        itemclick: me.onProductGroupClick
      }
    });
  },
  buildProductGroups: function(treePanel, eOpts) {
    var me = this;

    me.requestUtil.sendAjax("Getting all product groups", APP_ENV['countProductsGroupedByGroupNameRestUrl'], '', function(objResponse) {
      console.log("Response: ", objResponse);
      var children = me.getProductGroups(objResponse);

      var root = {
        expanded: true,
        children: children
      };

      treePanel.getStore().setRootNode(root);
    }, function(errorMessage) {
      me.dialogUtil.showErrorDialog(errorMessage);
    }, "GET");
  },
  onProductGroupClick: function(tree, record, item, index, e, options) {
    var me = this;

    var selectedGroup = record.raw.itemId;
    console.log("Selected: ", selectedGroup);

    var grid = me.getProductlist();
    console.log("Selected product list: ", grid);

    var filter = grid.filters.getFilter('group');
    if (filter) {
      filter.setValue(selectedGroup);
      filter.setActive(true);
    } else {
      grid.filters.addFilter({dataIndex: 'group', type: 'string', value: selectedGroup, active: true});
    }
    grid.filters.reload();
  },
  getProductGroups: function(objResponse) {
    var children = [];
    if (!Ext.isEmpty(objResponse)) {
      var objResponseData = objResponse.data;
      if (Array.isArray(objResponseData)) {
        Ext.each(objResponseData, function(item) {
          children.push({
            text: item.group + " (" + item.number + ")",
            qtip: item.group + " (" + item.number + ")",
            itemId: item.group,
            leaf: true
          });
        });
      } else {
        children.push({
          text: objResponseData.group + " (" + objResponseData.number + ")",
          qtip: objResponseData.group + " (" + objResponseData.number + ")",
          itemId: objResponseData.group,
          leaf: true
        });
      }
    } else {
      console.log("No product groups");
    }

    return children;
  }
});
