Ext.define('DataArt.view.product.List', {
  extend: 'Ext.grid.Panel',
  alias: 'widget.productlist',
  xtype: 'productlist',
  iconCls: 'icon-data-grid',
  title: 'Products',
  store: 'Products',
  columnLines: true,
  frame: true,
  loadMask: true,
  border: false,
  initComponent: function() {
    var me = this;
    // create config object
    var config = {};

    // build config properties
    Ext.apply(config, {
      features: me.buildFeatures(),
      columns: me.buildColumns(),
      dockedItems: me.buildDockedItems()
    });

    // apply config
    Ext.apply(me, Ext.apply(me.initialConfig, config));

    // call parent
    me.callParent(arguments);
  },
  // builders
  buildColumns: function() {
    var me = this;

    return [{
        header: APP_ENV['product.name'],
        dataIndex: 'name',
        renderer: function(value, meta, record) {
          meta.tdAttr = 'data-qtip="' + value + '"';
          return value;
        },
        width: 170,
        flex: 1
      }, {
        header: APP_ENV['product.price'],
        dataIndex: 'price',
        renderer: function(value, meta, record) {
          var newValue = Ext.util.Format.number(value, '0.00');
          meta.tdAttr = 'data-qtip="' + newValue + '"';
          return newValue;
        },
        xtype: 'numbercolumn',
        align: 'right',
        cls: 'x-form-num-column',
        width: 170,
        flex: 1
      }, {
        header: APP_ENV['product.group'],
        dataIndex: 'group',
        renderer: function(value, meta, record) {
          meta.tdAttr = 'data-qtip="' + value + '"';
          return value;
        },
        width: 170,
        flex: 1,
        filterable: true,
        filter: {
          type: 'string',
          dataIndex: 'group'
        }
      }];
  },
  buildDockedItems: function() {
    return [{
        xtype: 'pagingtoolbar',
        dock: 'top',
        store: 'Products',
        displayInfo: true,
        items: [],
        plugins: [{
            ptype: 'pagingtoolbarresizer',
            options: [10]
          }],
        listeners: {
          afterrender: function() {
            this.child('#refresh').hide();
          }
        }
      }];
  },
  buildFeatures: function() {
    return [{
        ftype: 'filters',
        // encode and local configuration options defined previously for easier reuse
        // json encode the filter query
        encode: true,
        // remote filtering
        local: false
      }];
  }
});
