package com.dataart.viewer.product.service.impl;

import com.dataart.viewer.product.mapper.ProductGroupMapper;
import com.dataart.viewer.product.model.impl.ProductGroup;
import com.dataart.viewer.product.model.vo.ProductGroupVO;
import com.dataart.viewer.product.repository.ProductGroupRepository;
import static org.mockito.Mockito.*;
import static org.junit.Assert.*;
import org.junit.Test;

/**
 *
 * @author volkodavav
 */
public class ProductGroupServiceDefaultTest {

    @Test
    public void testDeleteAllProducts() throws Exception {
        ProductGroupRepository productGroupRepository = mock(ProductGroupRepository.class);

        ProductGroupServiceDefault productGroupService = new ProductGroupServiceDefault();
        productGroupService.setProductGroupRepository(productGroupRepository);
        productGroupService.setProductGroupMapper(mock(ProductGroupMapper.class));

        productGroupService.afterPropertiesSet();
        productGroupService.deleteAllGroups();

        verify(productGroupRepository, times(1)).deleteAll();
    }

    @Test
    public void testSave() throws Exception {
        String FAKE_GROUP_NAME = "fakeGroup";
        ProductGroup FAKE_PRODUCT_GROUP = new ProductGroup(FAKE_GROUP_NAME);
        ProductGroupVO FAKE_PRODUCT_GROUP_VO = new ProductGroupVO(FAKE_GROUP_NAME);

        ProductGroupMapper productGroupMapper = mock(ProductGroupMapper.class);
        when(productGroupMapper.toPersistence(FAKE_PRODUCT_GROUP_VO)).thenReturn(FAKE_PRODUCT_GROUP);
        when(productGroupMapper.toVO(FAKE_PRODUCT_GROUP)).thenReturn(FAKE_PRODUCT_GROUP_VO);

        ProductGroupRepository productGroupRepository = mock(ProductGroupRepository.class);
        when(productGroupRepository.save(eq(FAKE_PRODUCT_GROUP))).thenReturn(FAKE_PRODUCT_GROUP);

        ProductGroupServiceDefault productGroupService = new ProductGroupServiceDefault();
        productGroupService.setProductGroupMapper(productGroupMapper);
        productGroupService.setProductGroupRepository(productGroupRepository);

        productGroupService.afterPropertiesSet();

        ProductGroupVO savedProductVO = productGroupService.save(FAKE_PRODUCT_GROUP_VO);

        verify(productGroupRepository, times(1)).save(FAKE_PRODUCT_GROUP);

        assertNotNull(savedProductVO);
        assertEquals(FAKE_GROUP_NAME, savedProductVO.getName());
    }

    @Test(expected = IllegalArgumentException.class)
    public void testSaveNullProductGroup() throws Exception {
        ProductGroupVO productGroupVO = null;

        ProductGroupServiceDefault productGroupService = new ProductGroupServiceDefault();
        productGroupService.setProductGroupMapper(mock(ProductGroupMapper.class));
        productGroupService.setProductGroupRepository(mock(ProductGroupRepository.class));

        productGroupService.afterPropertiesSet();

        ProductGroupVO savedProductVO = productGroupService.save(productGroupVO);
        assertTrue("Assert shouldn't be called", false);
    }
}
